@@ -1,12 +1,12 @@
 import json
 
 from flask_classful import FlaskView, route
-from flask_login import login_required
-from flask_security import current_user
+from flask_security import current_user, auth_required
 from marshmallow import fields
 from webargs.flaskparser import use_kwargs
 from werkzeug.exceptions import abort
 
+from flexmeasures.auth.policy import ADMIN_ROLE
 from flexmeasures.data.schemas.times import AwareDateTimeField
 from flexmeasures.data.models.time_series import Sensor
 
@@ -18,8 +18,8 @@ class SensorAPI(FlaskView):
     """
 
     route_base = "/sensor"
+    decorators = [auth_required()]
 
-    @login_required
     @route("/<id>/chart/")
     @use_kwargs(
         {
@@ -29,15 +29,19 @@ class SensorAPI(FlaskView):
             "beliefs_before": AwareDateTimeField(format="iso", required=False),
             "include_data": fields.Boolean(required=False),
             "dataset_name": fields.Str(required=False),
+            "height": fields.Str(required=False),
+            "width": fields.Str(required=False),
         },
         location="query",
     )
-    def get_chart(self, id, **kwargs):
-        """GET from /sensor/<id>/chart"""
+    def get_chart(self, id: int, **kwargs):
+        """GET from /sensor/<id>/chart
+
+        .. :quickref: Chart; Download a chart with time series
+        """
         sensor = get_sensor_or_abort(id)
         return json.dumps(sensor.chart(**kwargs))
 
-    @login_required
     @route("/<id>/chart_data/")
     @use_kwargs(
         {
@@ -48,17 +52,21 @@ class SensorAPI(FlaskView):
         },
         location="query",
     )
-    def get_chart_data(self, id, **kwargs):
+    def get_chart_data(self, id: int, **kwargs):
         """GET from /sensor/<id>/chart_data
 
+        .. :quickref: Chart; Download time series for use in charts
+
         Data for use in charts (in case you have the chart specs already).
         """
         sensor = get_sensor_or_abort(id)
         return sensor.search_beliefs(as_json=True, **kwargs)
 
-    @login_required
     def get(self, id: int):
-        """GET from /sensor/<id>"""
+        """GET from /sensor/<id>
+
+        .. :quickref: Chart; Download sensor attributes for use in charts
+        """
         sensor = get_sensor_or_abort(id)
         attributes = ["name", "timezone", "timerange"]
         return {attr: getattr(sensor, attr) for attr in attributes}
@@ -66,12 +74,12 @@ class SensorAPI(FlaskView):
 
 def get_sensor_or_abort(id: int) -> Sensor:
     sensor = Sensor.query.filter(Sensor.id == id).one_or_none()
+    if sensor is None:
+        raise abort(404, f"Sensor {id} not found")
     if not (
-        current_user.has_role("admin")
+        current_user.has_role(ADMIN_ROLE)
         or sensor.generic_asset.owner is None  # public
         or sensor.generic_asset.owner == current_user.account  # private but authorized
     ):
         raise abort(403)
-    if sensor is None:
-        raise abort(404, f"Sensor {id} not found")
     return sensor
