@@ -1,89 +1,146 @@
-from typing import List, Optional, Tuple, Union
+from typing import List, Optional, Type, Tuple, Union
 from datetime import datetime, timedelta
 
+from flask import current_app
+from flask_security import current_user
+from werkzeug.exceptions import Forbidden
 import pandas as pd
 import timely_beliefs as tb
-
 from sqlalchemy.orm import Query, Session
+from sqlalchemy.sql.elements import BinaryExpression
 
 from flexmeasures.data.config import db
+from flexmeasures.data.models.generic_assets import GenericAsset
 from flexmeasures.data.models.data_sources import DataSource
 from flexmeasures.utils import flexmeasures_inflection
 import flexmeasures.data.models.time_series as ts  # noqa: F401
+from flexmeasures.auth.policy import ADMIN_ROLE, ADMIN_READER_ROLE
 
 
 def create_beliefs_query(
-    cls: "ts.TimedValue",
+    cls: "Type[ts.TimedValue]",
     session: Session,
-    asset_class: db.Model,
-    asset_names: Tuple[str],
+    old_sensor_class: db.Model,
+    old_sensor_names: Tuple[str],
     start: Optional[datetime],
     end: Optional[datetime],
 ) -> Query:
     query = (
         session.query(
-            asset_class.name, cls.datetime, cls.value, cls.horizon, DataSource
+            old_sensor_class.name, cls.datetime, cls.value, cls.horizon, DataSource
         )
         .join(DataSource)
         .filter(cls.data_source_id == DataSource.id)
-        .join(asset_class)
-        .filter(asset_class.name.in_(asset_names))
+        .join(old_sensor_class)
+        .filter(old_sensor_class.name.in_(old_sensor_names))
     )
     if start is not None:
-        query = query.filter((cls.datetime > start - asset_class.event_resolution))
+        query = query.filter((cls.datetime > start - old_sensor_class.event_resolution))
     if end is not None:
         query = query.filter((cls.datetime < end))
     return query
 
 
-def add_user_source_filter(
-    cls: "ts.TimedValue", query: Query, user_source_ids: Union[int, List[int]]
+def potentially_limit_query_to_account_assets(
+    query: Query, account_id: Optional[int]
 ) -> Query:
-    """Add filter to the query to search only through user data from the specified user sources.
+    """Filter out all assets that are not in the current user's account.
+    For admins and CLI users, no assets are filtered out, unless an account_id is set.
+
+    :param account_id: if set, all assets that are not in the given account will be filtered out (only works for admins and CLI users). For querying public assets in particular, don't use this function.
+    """
+    if not current_user.is_authenticated and not current_app.cli:
+        raise Forbidden("Unauthenticated user cannot list assets.")
+    user_is_admin = (
+        current_app.cli
+        or current_user.has_role(ADMIN_ROLE)
+        or current_user.has_role(ADMIN_READER_ROLE)
+    )
+    if account_id is None and user_is_admin:
+        return query  # allow admins to query assets across all accounts
+    if (
+        account_id is not None
+        and account_id != current_user.account_id
+        and not user_is_admin
+    ):
+        raise Forbidden("Non-admin cannot access assets from other accounts.")
+    account_id_to_filter = (
+        account_id if account_id is not None else current_user.account_id
+    )
+    return query.filter(
+        (
+            GenericAsset.account_id == account_id_to_filter
+            or GenericAsset.account_id is None
+        )
+    )
+
+
+def get_source_criteria(
+    cls: "Union[Type[ts.TimedValue], Type[ts.TimedBelief]]",
+    user_source_ids: Union[int, List[int]],
+    source_types: List[str],
+    exclude_source_types: List[str],
+) -> List[BinaryExpression]:
+    source_criteria: List[BinaryExpression] = []
+    if user_source_ids is not None:
+        source_criteria.append(user_source_criterion(cls, user_source_ids))
+    if source_types is not None:
+        if user_source_ids and "user" not in source_types:
+            source_types.append("user")
+        source_criteria.append(source_type_criterion(source_types))
+    if exclude_source_types is not None:
+        if user_source_ids and "user" in exclude_source_types:
+            exclude_source_types.remove("user")
+        source_criteria.append(source_type_exclusion_criterion(exclude_source_types))
+    return source_criteria
+
+
+def user_source_criterion(
+    cls: "Union[Type[ts.TimedValue], Type[ts.TimedBelief]]",
+    user_source_ids: Union[int, List[int]],
+) -> BinaryExpression:
+    """Criterion to search only through user data from the specified user sources.
 
     We distinguish user sources (sources with source.type == "user") from other sources (source.type != "user").
     Data with a user source originates from a registered user. Data with e.g. a script source originates from a script.
 
-    This filter doesn't affect the query over non-user type sources.
+    This criterion doesn't affect the query over non-user type sources.
     It does so by ignoring user sources that are not in the given list of source_ids.
     """
     if user_source_ids is not None and not isinstance(user_source_ids, list):
         user_source_ids = [user_source_ids]  # ensure user_source_ids is a list
-    if user_source_ids:
-        ignorable_user_sources = (
-            DataSource.query.filter(DataSource.type == "user")
-            .filter(DataSource.id.notin_(user_source_ids))
-            .all()
-        )
-        ignorable_user_source_ids = [
-            user_source.id for user_source in ignorable_user_sources
-        ]
-        query = query.filter(cls.data_source_id.notin_(ignorable_user_source_ids))
-    return query
+    ignorable_user_sources = (
+        DataSource.query.filter(DataSource.type == "user")
+        .filter(DataSource.id.not_in(user_source_ids))
+        .all()
+    )
+    ignorable_user_source_ids = [
+        user_source.id for user_source in ignorable_user_sources
+    ]
+
+    # todo: [legacy] deprecate this if-statement, which is used to support the TimedValue class
+    if hasattr(cls, "data_source_id"):
+        return cls.data_source_id.not_in(ignorable_user_source_ids)
+    return cls.source_id.not_in(ignorable_user_source_ids)
 
 
-def add_source_type_filter(
-    cls: "ts.TimedValue", query: Query, source_types: List[str]
-) -> Query:
-    """Add filter to the query to collect only data from sources that are of the given type."""
-    return query.filter(DataSource.type.in_(source_types)) if source_types else query
+def source_type_criterion(source_types: List[str]) -> BinaryExpression:
+    """Criterion to collect only data from sources that are of the given type."""
+    return DataSource.type.in_(source_types)
 
 
-def exclude_source_type_filter(
-    cls: "ts.TimedValue", query: Query, source_types: List[str]
-) -> Query:
-    """Add filter to the query to exclude sources that are of the given type."""
-    return query.filter(DataSource.type.notin_(source_types)) if source_types else query
+def source_type_exclusion_criterion(source_types: List[str]) -> BinaryExpression:
+    """Criterion to exclude sources that are of the given type."""
+    return DataSource.type.not_in(source_types)
 
 
-def add_belief_timing_filter(
-    cls: "ts.TimedValue",
-    query: Query,
+def get_belief_timing_criteria(
+    cls: "Type[ts.TimedValue]",
     asset_class: db.Model,
     belief_horizon_window: Tuple[Optional[timedelta], Optional[timedelta]],
     belief_time_window: Tuple[Optional[datetime], Optional[datetime]],
-) -> Query:
-    """Add filters for the desired windows with relevant belief times and belief horizons.
+) -> List[BinaryExpression]:
+    """Get filter criteria for the desired windows with relevant belief times and belief horizons.
 
     # todo: interpret belief horizons with respect to knowledge time rather than event end.
     - a positive horizon denotes a before-the-fact belief (ex-ante w.r.t. knowledge time)
@@ -121,24 +178,25 @@ def add_belief_timing_filter(
         belief_time_window = (None, datetime(2020, 5, 13))
 
     """
+    criteria: List[BinaryExpression] = []
     earliest_belief_time, latest_belief_time = belief_time_window
     if (
         earliest_belief_time is not None
         and latest_belief_time is not None
         and earliest_belief_time == latest_belief_time
     ):  # search directly for a unique belief time
-        query = query.filter(
+        criteria.append(
             cls.datetime + asset_class.event_resolution - cls.horizon
             == earliest_belief_time
         )
     else:
         if earliest_belief_time is not None:
-            query = query.filter(
+            criteria.append(
                 cls.datetime + asset_class.event_resolution - cls.horizon
                 >= earliest_belief_time
             )
         if latest_belief_time is not None:
-            query = query.filter(
+            criteria.append(
                 cls.datetime + asset_class.event_resolution - cls.horizon
                 <= latest_belief_time
             )
@@ -148,13 +206,13 @@ def add_belief_timing_filter(
         and long_horizon is not None
         and short_horizon == long_horizon
     ):  # search directly for a unique belief horizon
-        query = query.filter(cls.horizon == short_horizon)
+        criteria.append(cls.horizon == short_horizon)
     else:
         if short_horizon is not None:
-            query = query.filter(cls.horizon >= short_horizon)
+            criteria.append(cls.horizon >= short_horizon)
         if long_horizon is not None:
-            query = query.filter(cls.horizon <= long_horizon)
-    return query
+            criteria.append(cls.horizon <= long_horizon)
+    return criteria
 
 
 def simplify_index(
