@@ -4,14 +4,10 @@ For example, group by asset type or by location.
 """
 
 from __future__ import annotations
-from typing import List, Dict, Optional, Union
+from typing import List, Dict, Optional
 import inflect
-from itertools import groupby
 
 from sqlalchemy.orm import Query
-from flask_security import current_user
-from werkzeug.exceptions import Forbidden
-from flexmeasures.auth.policy import ADMIN_ROLE, ADMIN_READER_ROLE
 
 from flexmeasures.utils.flexmeasures_inflection import parameterize, pluralize
 from flexmeasures.data.models.generic_assets import (
@@ -19,7 +15,10 @@ from flexmeasures.data.models.generic_assets import (
     GenericAsset,
     assets_share_location,
 )
-from flexmeasures.data.queries.generic_assets import query_assets_by_type
+from flexmeasures.data.queries.generic_assets import (
+    query_assets_by_type,
+    get_location_queries,
+)
 
 p = inflect.engine()
 
@@ -57,68 +56,6 @@ def get_asset_group_queries(
     if group_by_location:
         asset_queries.update(get_location_queries())
 
-    if not (
-        current_user.has_role(ADMIN_ROLE) or current_user.has_role(ADMIN_READER_ROLE)
-    ):
-        # only current user's account
-        asset_queries = limit_assets_to_account(asset_queries)
-
-    return asset_queries
-
-
-def get_location_queries() -> Dict[str, Query]:
-    """
-    Make queries for grouping assets by location.
-
-    We group EVSE assets by location (if they share a location, they belong to the same Charge Point)
-    Like get_asset_group_queries, the values in the returned dict still need an executive call, like all(), count() or first(). Note that this function will still load and inspect assets to do its job.
-
-    The Charge Points are named on the basis of the first EVSE in their list,
-    using either the whole EVSE name or that part that comes before a " -" delimiter. For example:
-    If:
-        evse_name = "Seoul Hilton - charger 1"
-    Then:
-        charge_point_name = "Seoul Hilton (Charge Point)"
-
-    A Charge Point is a special case. If all assets on a location are of type EVSE,
-    we can call the location a "Charge Point".
-    """
-    asset_queries = {}
-    all_assets = GenericAsset.query.all()
-    loc_groups = group_assets_by_location(all_assets)
-    for loc_group in loc_groups:
-        if len(loc_group) == 1:
-            continue
-        location_type = "(Location)"
-        if all(
-            [
-                asset.asset_type.name in ["one-way_evse", "two-way_evse"]
-                for asset in loc_group
-            ]
-        ):
-            location_type = "(Charge Point)"
-        location_name = f"{loc_group[0].name.split(' -')[0]} {location_type}"
-        asset_queries[location_name] = GenericAsset.query.filter(
-            GenericAsset.name.in_([asset.name for asset in loc_group])
-        )
-    return asset_queries
-
-
-def limit_assets_to_account(
-    asset_queries: Union[Query, Dict[str, Query]]
-) -> Union[Query, Dict[str, Query]]:
-    """Filter out any assets that are not in the user's account."""
-    if not hasattr(current_user, "account_id"):
-        raise Forbidden("Unauthenticated user cannot list asset groups.")
-    if isinstance(asset_queries, dict):
-        for name, query in asset_queries.items():
-            asset_queries[name] = query.filter(
-                GenericAsset.account_id == current_user.account.id
-            )
-    else:
-        asset_queries = asset_queries.filter(
-            GenericAsset.account_id == current_user.account_id
-        )
     return asset_queries
 
 
@@ -178,7 +115,7 @@ class AssetGroup:
 
     def is_eligible_for_comparing_individual_traces(self, max_traces: int = 7) -> bool:
         """
-        Decide whether comparing individual traces for assets in this resource
+        Decide whether comparing individual traces for assets in this asset group
         is a useful feature.
         The number of assets that can be compared is parametrizable with max_traces.
         Plot colors are reused if max_traces > 7, and run out if max_traces > 105.
@@ -206,17 +143,3 @@ class AssetGroup:
 
     def __str__(self):
         return self.display_name
-
-
-def group_assets_by_location(
-    asset_list: List[GenericAsset],
-) -> List[List[GenericAsset]]:
-    groups = []
-
-    def key_function(x):
-        return x.location if x.location else ()
-
-    sorted_asset_list = sorted(asset_list, key=key_function)
-    for _k, g in groupby(sorted_asset_list, key=key_function):
-        groups.append(list(g))
-    return groups
